package com.yunzhi.demo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.demo.common.BaseController;
import com.yunzhi.demo.common.Constants;
import com.yunzhi.demo.common.ResponseBean;
import com.yunzhi.demo.common.StringUtils;
import com.yunzhi.demo.entity.TaPersonData;
import com.yunzhi.demo.entity.TdSchool;
import com.yunzhi.demo.entity.TdSpecialty;
import com.yunzhi.demo.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.demo.entity.TaPerson;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * <p>
    * 人员 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-04-15
 */

@Api(tags = "人员")
@RestController
@RequestMapping("/")
public class TaPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPersonController.class);

    @Autowired
    ITaPersonService iTaPersonService;

    @Autowired
    ITaPersonDataService iTaPersonDataService;

    @Autowired
    ITdSchoolService iTdSchoolService;

    @Autowired
    ITdSpecialtyService iTdSpecialtyService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/person",method= RequestMethod.GET)
    @ApiOperation(value="查询学生列表", notes = "查询学生列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPersonList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                     @ApiParam("名称") @RequestParam(value ="name", required = false) String name,
                                     @ApiParam("学校ID") @RequestParam(value ="schoolId", required = false) String schoolId,
                                     @ApiParam("专业ID") @RequestParam(value ="specialtyId", required = false) String specialtyId,
                                     @ApiParam("手机") @RequestParam(value ="phone", required = false) String phone,
                                     @ApiParam("学号") @RequestParam(value ="studentId", required = false) String studentId) throws Exception{

		    IPage<TaPerson> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<TaPerson>()
                    .gt("status", Constants.STATUS_DELETED)
                    .like(!StringUtils.isEmpty(name), "name", "%"+name+"%")
                    .eq(!StringUtils.isEmpty(schoolId), "school_id", schoolId)
                    .eq(!StringUtils.isEmpty(specialtyId), "specialty_id", specialtyId)
                    .like(!StringUtils.isEmpty(phone), "phone", "%"+phone+"%")
                    .like(!StringUtils.isEmpty(studentId), "student_id", "%"+studentId+"%")
                    .orderByDesc("create_date");

            IPage<TaPerson> result = iTaPersonService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

//    /**
//     * 保存对象
//     * @param taPerson 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taPerson",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taPersonAdd(@ApiParam("保存内容") @RequestBody TaPerson taPerson) throws Exception{
//
//        if (iTaPersonService.save(taPerson)){
//            return ResponseBean.success(taPerson);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPerson/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taPersonDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaPersonService.removeById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

    /**
     * 小程序完善信息
     * @param taPerson 实体对象
     * @return
     */
    @RequestMapping(value="/ma/person",method= RequestMethod.PUT)
    @ApiOperation(value="小程序完善信息", notes = "更新当前人自己的信息", httpMethod = "PUT", response = TaPerson.class)
    public ResponseBean taPersonUpdate(@ApiParam("更新内容") @RequestBody TaPerson taPerson) throws Exception{
        TaPerson currentPerson = getCurrentPerson();
        if (null == currentPerson || null == taPerson || !currentPerson.getPersonId().equals(taPerson.getPersonId())) {
            throw new Exception("校验人员信息失败");
        }

        taPerson.setUpdateDate(LocalDateTime.now());

        if (iTaPersonService.updateById(taPerson)){
            return ResponseBean.success(iTaPersonService.getById(taPerson.getPersonId()));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/person/{id}",method= RequestMethod.GET)
    @ApiOperation(value="学生详情", notes = "查询人员详细信息", httpMethod = "GET", response = TaPerson.class)
    public ResponseBean taPersonGet(@ApiParam("学生ID") @PathVariable String id) throws Exception{
        TaPerson taPerson = iTaPersonService.getById(id);
        if (null == taPerson || Constants.STATUS_DELETED.equals(taPerson.getStatus())) {
            throw new Exception("验证人员信息失败, 请退出重试");
        }

        fillInfo(taPerson);

        return ResponseBean.success(taPerson);
    }

    @GetMapping("/ma/currentPerson")
    @ApiOperation(value="小程序当前人员", notes = "获取当前人员信息", httpMethod = "GET", response = TaPerson.class)
    public ResponseBean getCurrent() throws Exception {
        TaPerson taPerson = getCurrentPerson();
        if (null == taPerson) {
            throw new Exception("验证人员信息失败, 请退出重试");
        }

        fillInfo(taPerson);

        return ResponseBean.success(taPerson);
    }

    private void fillInfo(TaPerson taPerson) {
        // 冗余学校名称, 专业名称
        if (null != taPerson.getSchoolId()) {
            TdSchool tdSchool = iTdSchoolService.getById(taPerson.getSchoolId());
            if (null != tdSchool) {
                taPerson.setSchoolName(tdSchool.getName());
            }

            TdSpecialty tdSpecialty = iTdSpecialtyService.getById(taPerson.getSpecialtyId());
            if (null != tdSpecialty) {
                taPerson.setSpecialtyName(tdSpecialty.getName());
            }
        }

        // 获取统计数据
        TaPersonData taPersonData = iTaPersonDataService.getById(taPerson.getPersonId());
        taPerson.setPersonData(taPersonData);
    }
}
