package com.yunzhi.demo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.demo.common.BaseController;
import com.yunzhi.demo.common.Constants;
import com.yunzhi.demo.common.ResponseBean;
import com.yunzhi.demo.entity.TaPerson;
import com.yunzhi.demo.entity.TaPost;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.demo.service.ITaPostSaveService;
import com.yunzhi.demo.entity.TaPostSave;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;

/**
 * <p>
    * 收藏 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-04-15
 */

@Api(tags = "收藏")
@RestController
@RequestMapping("/")
public class TaPostSaveController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPostSaveController.class);

    @Autowired
    public ITaPostSaveService iTaPostSaveService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/ma/post-save",method= RequestMethod.GET)
    @ApiOperation(value="我的收藏", notes = "小程序我的收藏列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPostSaveList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<TaPost> pg = new Page<>(pageNum, pageSize);
        TaPerson taPerson = getCurrentPerson();

        IPage<TaPost> result = iTaPostSaveService.getMyPostSaveList(pg, taPerson.getPersonId());
        return ResponseBean.success(result);
    }

    /**
     * 添加收藏
     * @param postId 文章ID
     * @return
     */
    @RequestMapping(value="/ma/post-save",method= RequestMethod.POST)
    @ApiOperation(value="添加我的收藏", notes = "添加我的收藏", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taPostSaveAdd(@ApiParam("文章ID") @RequestParam String postId) throws Exception{
        TaPerson taPerson = getCurrentPerson();
        TaPostSave taPostSave = new TaPostSave();
        taPostSave.setPostId(postId);
        taPostSave.setPersonId(taPerson.getPersonId());

        // 先校验是否存在
        boolean saved = iTaPostSaveService.checkSaved(taPerson.getPersonId(), postId);
        if (saved) {
            return ResponseBean.success("已收藏");
        }

        if (iTaPostSaveService.save(taPostSave)){
            return ResponseBean.success(taPostSave);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 取消我的收藏
     * @param postId  文章ID
     */
    @RequestMapping(value="/ma/post-save", method= RequestMethod.DELETE)
    @ApiOperation(value="取消我的收藏", notes = "取消我的收藏", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taPostSaveDelete(@ApiParam("文章ID") @RequestParam String postId) throws Exception{
        TaPerson taPerson = getCurrentPerson();
        TaPostSave taPostSave = iTaPostSaveService.getMyPostSave(taPerson.getPersonId(), postId);

        if (null == taPostSave) {
            return ResponseBean.success("已取消收藏");
        }

        taPostSave.setStatus(Constants.STATUS_DELETED);
        taPostSave.setUpdateDate(LocalDateTime.now());

        if(iTaPostSaveService.updateById(taPostSave)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("取消我的收藏失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taPostSave 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taPostSave/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taPostSaveUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaPostSave taPostSave) throws Exception{
//
//        if (iTaPostSaveService.updateById(taPostSave)){
//            return ResponseBean.success(iTaPostSaveService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPostSave/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPostSaveGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaPostSaveService.getById(id));
    }
}
