package com.yunzhi.demo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.demo.common.BaseController;
import com.yunzhi.demo.common.ResponseBean;
import com.yunzhi.demo.common.StringUtils;
import com.yunzhi.demo.entity.MyReadLog;
import com.yunzhi.demo.entity.TaPerson;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.demo.service.ITaReadLogService;
import com.yunzhi.demo.entity.TaReadLog;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 阅读记录 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-04-15
 */

@Api(tags = "阅读记录")
@RestController
@RequestMapping("/")
public class TaReadLogController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaReadLogController.class);

    @Autowired
    public ITaReadLogService iTaReadLogService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/ma/read-log",method= RequestMethod.GET)
    @ApiOperation(value="我的阅读记录", notes = "我的阅读记录", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taReadLogList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                      @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{
        TaPerson taPerson = getCurrentPerson();
        IPage<MyReadLog> pg = new Page<>(pageNum, pageSize);
        IPage<MyReadLog> result = iTaReadLogService.getMyReadList(pg, taPerson.getPersonId());
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taReadLog 实体对象
     * @return
     */
    @RequestMapping(value="/taReadLog",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taReadLogAdd(@ApiParam("保存内容") @RequestBody TaReadLog taReadLog) throws Exception{

        if (iTaReadLogService.save(taReadLog)){
            return ResponseBean.success(taReadLog);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taReadLog/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taReadLogDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaReadLogService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 更新文章阅读时长
     * @param taReadLog 实体对象
     * @return
     */
    @RequestMapping(value="/ma/read-log",method= RequestMethod.PUT)
    @ApiOperation(value="更新文章阅读时长", notes = "更新文章阅读时长", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taReadLogUpdate(@ApiParam("更新内容") @RequestBody TaReadLog taReadLog) throws Exception{
        if (StringUtils.isEmpty(taReadLog.getPostId()) || null == taReadLog.getDuration()) {
            throw new Exception("未设置更新文章及时长");
        }

        TaPerson taPerson = getCurrentPerson();
        iTaReadLogService.updateDuration(taPerson.getPersonId(), taReadLog.getPostId(), taReadLog.getDuration());

        return ResponseBean.success("更新成功");
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taReadLog/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taReadLogGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaReadLogService.getById(id));
    }
}
